==> workplayerapi-1.0.50.tgz: package/config/unlogged.js <==
/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import axios from 'axios';

import { PROD, DEV } from './constants';

let currentEnvironment = null;

export function setEnvironment(env) {
    if (env === 'debug') currentEnvironment = DEV;
    else currentEnvironment = PROD;
}

const unlogged = axios.create({
    baseURL        : currentEnvironment,
    validateStatus : status => { return status < 500; }
});

unlogged.defaults.headers.post['Content-Type'] = 'application/json';
unlogged.defaults.headers.get['Content-Type'] = 'application/json';
unlogged.defaults.timeout = 2500;

unlogged.interceptors.request.use(request => {
        return request;
    },
    error => Promise.reject(error)
);

unlogged.interceptors.response.use(response => {
        return response;
    },
    error => Promise.reject(error)
);

export default unlogged;

==> workplayerapi-1.0.51.tgz: package/config/unlogged.js <==
/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import axios from 'axios';

import { PROD, DEV } from './constants';

export let currentEnvironment = null;

export function setEnvironment(env) {
    if (env === 'debug') currentEnvironment = DEV;
    else currentEnvironment = PROD;
}

const unlogged = axios.create({
    baseURL        : currentEnvironment,
    validateStatus : status => { return status < 500; }
});

unlogged.defaults.headers.post['Content-Type'] = 'application/json';
unlogged.defaults.headers.get['Content-Type'] = 'application/json';
unlogged.defaults.timeout = 2500;

unlogged.interceptors.request.use(request => {
        return request;
    },
    error => Promise.reject(error)
);

unlogged.interceptors.response.use(response => {
        return response;
    },
    error => Promise.reject(error)
);

export default unlogged;
